@@ -24,14 +24,12 @@ try:
     from requests import get
     from googlesearch import get_random_user_agent
     from bs4 import BeautifulSoup as bs
-    from urllib import parse
 except ImportError:
     print('ImportError\nInstalling missing packages...')
     from subprocess import run
     run(['pip3', 'install', 'requests'])
     run(['pip3', 'install', 'google'])
     run(['pip3', 'install', 'beautifulsoup4'])
-    run(['pip3', 'install', 'urllib'])
 
 
 # variables
@@ -357,12 +355,8 @@ def fib(x):
     return a
 
 
+## -------------------- OEIS -------------------- ##
 
-###############################
-#                             #
-#            OEIS             #
-#                             #
-###############################
 
 def _result(table, word):
         try:
@@ -524,7 +518,7 @@ def info(x = 0):
 
     if x == 0:
         print(f'\n{__pack.upper()}\n'
-            '\nver. 2.0.8\n'
+            '\nver. 2.0.9\n'
             f'\nHere the {str(len(funcdict))} functions available in {__pack}\n')
         for i in funcdict.keys():
             print('>>> ' + i)
